@@ -8,9 +8,15 @@
 /* Bug report URL. */
 #define BUG_REPORT_URL "http://llvm.org/bugs/"
 
+/* Default linker to use. */
+#define CLANG_DEFAULT_LINKER ""
+
 /* Default C++ stdlib to use. */
 #define CLANG_DEFAULT_CXX_STDLIB ""
 
+/* Default runtime library to use. */
+#define CLANG_DEFAULT_RTLIB ""
+
 /* Default OpenMP runtime used by -fopenmp. */
 #define CLANG_DEFAULT_OPENMP_RUNTIME "libomp"
 
@@ -32,8 +38,11 @@
 /* Define if we have libxml2 */
 #define CLANG_HAVE_LIBXML 1
 
+/* Define if we have sys/resource.h (rlimits) */
+#define CLANG_HAVE_RLIMITS 1
+
 /* The LLVM product name and version */
-#define BACKEND_PACKAGE_STRING "LLVM 3.9.0"
+#define BACKEND_PACKAGE_STRING "LLVM 4.0.1"
 
 /* Linker version detected at compile time. */
 /* #undef HOST_LINK_VERSION */
